@@ -13,7 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import sys
-import mock
+from unittest import mock
 
 from oslo_utils import uuidutils
 
