@@ -204,6 +204,22 @@ class Config(object):
                                                                str(e))
                 raise OSError(message)
 
+        os.makedirs(config_dir, mode=0o700, exist_ok=True)
+
+        # Create Runner friendly directory structure
+        # https://ansible-runner.readthedocs.io/en/stable/intro.html#runner-artifacts-directory-hierarchy
+        structure = [
+            'artifacts',
+            'env',
+            'inventory',
+            'profiling_data',
+            'project',
+            'roles',
+        ]
+        for d in structure:
+            os.makedirs(os.path.join(config_dir, d), mode=0o700,
+                        exist_ok=True)
+
     def fetch_config(self, name):
         # Get the stack object
         stack = self.client.stacks.get(name)
@@ -261,10 +277,6 @@ class Config(object):
                     filepath = os.path.join(role_path, 'param_config.json')
                     with self._open_file(filepath) as param_config:
                         param_config.write(json.dumps(role[config]))
-                elif config == 'ansible_group_vars':
-                    role_config = role[config].copy()
-                    role_config.update(role_group_vars[role_name])
-                    role_group_vars[role_name] = role_config
                 else:
                     # NOTE(emilien): Move this condition to the
                     # upper level once THT is adapted for all tasks to be
