@@ -13,11 +13,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import base64
+from cryptography.hazmat.primitives import serialization
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.backends import default_backend
 import hashlib
 import hmac
 import logging
 import os
-import paramiko
 import struct
 import time
 import uuid
@@ -53,6 +55,10 @@ def generate_passwords(stack_env=None,
             stack_env and name in stack_env.get(
                 'parameter_defaults', {})):
             passwords[name] = stack_env['parameter_defaults'][name]
+        elif (name == 'KeystonePassword' and stack_env and
+                'AdminToken' in stack_env.get('parameter_defaults', {})):
+            # NOTE(tkajinam): AdminToken was renamed to KeystonePassword
+            passwords[name] = stack_env['parameter_defaults']['AdminToken']
         elif name in ('CephClientKey', 'CephManilaClientKey', 'CephRgwKey'):
             # CephX keys aren't random strings
             passwords[name] = create_cephx_key()
@@ -151,11 +157,17 @@ def create_ssh_keypair(comment=None, bits=2048):
     """Generate an ssh keypair for use on the overcloud"""
     if comment is None:
         comment = "Generated by TripleO"
-    key = paramiko.RSAKey.generate(bits)
-    keyout = six.StringIO()
-    key.write_private_key(keyout)
-    private_key = keyout.getvalue()
-    public_key = '{} {} {}'.format(key.get_name(), key.get_base64(), comment)
+    key = rsa.generate_private_key(public_exponent=65537,
+                                   key_size=bits,
+                                   backend=default_backend())
+    private_key = key.private_bytes(
+        serialization.Encoding.PEM,
+        serialization.PrivateFormat.PKCS8,
+        serialization.NoEncryption()).decode('utf-8')
+    public_key = key.public_key().public_bytes(
+        serialization.Encoding.OpenSSH,
+        serialization.PublicFormat.OpenSSH).decode('utf-8')
+    public_key = '{} {}'.format(public_key, comment)
     return {
         'private_key': private_key,
         'public_key': public_key,
